@@ -6,14 +6,14 @@ use warnings;
 use Moo;
 use MooX::Types::MooseLike::Base qw/ ArrayRef HashRef Int Str /;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Data::Dump 'dump';
 use DateTime;
 use Devel::StackTrace;
 use English '-no_match_vars';
+use HTTP::Request::Common 'POST';
 use HTTP::Status ':constants';
-use IO::Compress::Gzip 'gzip';
 use JSON::XS;
 use LWP::UserAgent;
 use Sys::Hostname;
@@ -57,7 +57,7 @@ Sentry::Raven - A perl sentry client
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =head1 SYNOPSIS
 
@@ -496,17 +496,6 @@ sub _construct_query_event {
     );
 };
 
-sub _compress_event_json {
-    my ($self, $event_json) = @_;
-
-    my $compressed_event_json;
-
-    gzip(\$event_json, \$compressed_event_json)
-        or die "failed to compress event";
-
-    return $compressed_event_json;
-}
-
 sub _post_event {
     my ($self, $event) = @_;
 
@@ -517,17 +506,15 @@ sub _post_event {
     eval {
         my $event_json = $self->json_obj()->encode( $event );
 
-        $event_json = $self->_compress_event_json($event_json)
-            if $event->{encoding} eq 'gzip';
-
         $self->ua_obj()->timeout($self->timeout());
 
-        $response = $self->ua_obj()->post(
+        my $request = POST(
             $self->post_url(),
             'X-Sentry-Auth'    => $self->_generate_auth_header(),
             Content            => $event_json,
-            ($event->{encoding} eq 'gzip' ? ('Content-encoding' => 'gzip') : ()),
         );
+        $request->encode( $event->{encoding} );
+        $response = $self->ua_obj()->request($request);
 
         $response_code = $response->code();
         $response_content = $response->content();
@@ -636,7 +623,11 @@ sub _generate_auth_header {
 }
 
 sub _build_json_obj { JSON::XS->new()->utf8(1)->pretty(1)->allow_nonref(1) }
-sub _build_ua_obj { LWP::UserAgent->new() }
+sub _build_ua_obj {
+    return LWP::UserAgent->new(
+        keep_alive => 1,
+    );
+}
 
 =head1 EVENT CONTEXT
 
